@@ -1,5 +1,14 @@
 import os
 
+from _pyinstaller_hooks_contrib.compat import importlib_metadata
+import packaging.version
+
+try:
+    vtk_version = packaging.version.Version(importlib_metadata.version('vtk')).release
+except Exception:
+    vtk_version = None
+
+
 # This list of dependencies was obtained via analysis based on code in `vtkmodules/generate_pyi.py` and augmented with
 # missing entries until all tests from `test_vtkmodules` pass. Instead of a pre-computed list, we could dynamically
 # analyze each module when the hook is executed; however, such approach would be slower, and would also not account
@@ -194,6 +203,10 @@ _module_dependencies = {
         'vtkmodules.vtkIOImage',
         'vtkmodules.vtkIOXML',
     ],
+    'vtkmodules.vtkIOAvmesh': [
+        'vtkmodules.vtkCommonExecutionModel',
+        'vtkmodules.vtkIOCore',
+    ],
     'vtkmodules.vtkIOCGNSReader': [
         'vtkmodules.vtkCommonExecutionModel',
     ],
@@ -285,6 +298,7 @@ _module_dependencies = {
     ],
     'vtkmodules.vtkIOImport': [
         'vtkmodules.vtkCommonExecutionModel',
+        'vtkmodules.vtkIOCore',
         'vtkmodules.vtkRenderingCore',
     ],
     'vtkmodules.vtkIOImage': [
@@ -296,6 +310,9 @@ _module_dependencies = {
         'vtkmodules.vtkIOLegacy',
         'vtkmodules.vtkIOXML',
     ],
+    'vtkmodules.vtkIOLANLX3D': [
+        'vtkmodules.vtkCommonExecutionModel',
+    ],
     'vtkmodules.vtkIOLSDyna': [
         'vtkmodules.vtkCommonExecutionModel',
         'vtkmodules.vtkIOXMLParser',
@@ -479,6 +496,10 @@ _module_dependencies = {
         'vtkmodules.vtkCommonExecutionModel',
         'vtkmodules.vtkRenderingCore',
     ],
+    'vtkmodules.vtkRenderingGridAxes': [
+        'vtkmodules.vtkChartsCore',
+        'vtkmodules.vtkRenderingCore',
+    ],
     'vtkmodules.vtkRenderingGL2PSOpenGL2': [
         'vtkmodules.vtkRenderingOpenGL2',
     ],
@@ -556,6 +577,10 @@ _module_dependencies = {
         'vtkmodules.vtkIOXML',
         'vtkmodules.vtkRenderingCore',
     ],
+    'vtkmodules.vtkTestingSerialization': [
+        'vtkmodules.vtkCommonDataModel',
+        'vtkmodules.vtkSerializationManager',
+    ],
     'vtkmodules.vtkViewsContext2D': [
         'vtkmodules.vtkRenderingCore',
         'vtkmodules.vtkViewsCore',
@@ -576,6 +601,15 @@ _module_dependencies = {
     ],
 }
 
+# Additional hidden imports for vtk 9.6.0
+if vtk_version is not None and vtk_version >= (9, 6, 0):
+    # Additional
+    _module_dependencies['vtkmodules.vtkIOImage'] += ['vtkmodules.vtkIOCore']
+    _module_dependencies['vtkmodules.vtkViewsInfovis'] += ['vtkmodules.vtkChartsCore']
+
+    # New
+    _module_dependencies['vtkmodules.vtkSerializationManager'] = ['vtkmodules.vtkCommonDataModel']
+
 
 def add_vtkmodules_dependencies(hook_file):
     # Find the module underlying this vtkmodules hook: change `/path/to/hook-vtkmodules.blah.py` to `vtkmodules.blah`.
